@@ -38,5 +38,5 @@ class HQBootstrapController(EventSubscriber[UserInput]):
     def run(self, data: UserInput) -> UserInput:
         self._cryptographic_key_deriver.create_salt()
 
-        self._state_data_manager.create_hq_state(data)
+        self._state_data_manager.create_hq_state()
         return data
