@@ -127,6 +127,17 @@ class UserInput(BaseModel):
         category='bootstrap',
     )] = SecretRetrievalMethod.WG_FEDERATION_ENV_VAR_OR_FILE
 
+    wg_interface_restart: Annotated[bool, Field(
+        title='Prevent WG system interface’s restart',
+        description='Sets whether or not the bootstrap should restart the system’s WireGuard interfaces. '
+                    'Unless specific needs, bootstrapping do not need to restart system’s WireGuard interfaces.',
+        type=bool,
+        true_type=bool,
+        argparse_action=ArgparseAction.STORE_TRUE,
+        argument_short='-r',
+        category='bootstrap',
+    )] = False
+
     # [hq] get-private-key
     interface_name: Annotated[str, Field(
         title='WireGuard Interface Name',
