@@ -1,3 +1,4 @@
+import hashlib
 import re
 from typing import Any
 
@@ -62,6 +63,16 @@ class WireguardInterface(BaseModel, frozen=True):
         """
         return tuple(map(cls.from_dict, configurations))
 
+    def into_sha256_digest(self) -> str:
+        """
+        Transform the current object into its matching sh256 digest
+        :return:
+        """
+        # While the WireGuard INI is the most reliable way to get a digest if this object content…
+        # the public/private key pair does not always appear in it, because of post_up
+        # that’s why the public key is added to the mix
+        return hashlib.sha256((str(self.into_wireguard_ini()) + self.public_key).encode('UTF-8')).hexdigest()
+
     def into_wireguard_ini(self) -> dict:
         """
         Transform the current object into a dict specifically made for WireGuard configuration files
