@@ -1,7 +1,7 @@
 from abc import ABC
 from io import TextIOWrapper
 from types import ModuleType
-from typing import Any, TextIO
+from typing import Any, IO
 
 from wg_federation.data_transformation.loader.configuration_loader_interface import ConfigurationLoaderInterface
 from wg_federation.utils.utils import Utils
@@ -32,7 +32,7 @@ class FileConfigurationLoader(ConfigurationLoaderInterface, ABC):
         return (isinstance(source, str) and self._os_path_lib.exists(source)) \
             or isinstance(source, TextIOWrapper)
 
-    def _load_file(self, file: TextIO) -> dict:
+    def _load_file(self, file: IO[Any]) -> dict:
         """
         Process an open file and returns configuration
         :param file: open file handler
