@@ -1,5 +1,5 @@
 import json
-from typing import Any, TextIO
+from typing import Any, IO
 
 from wg_federation.data_transformation.loader.file.file_configuration_loader import FileConfigurationLoader
 from wg_federation.utils.utils import Utils
@@ -14,6 +14,6 @@ class JsonFileConfigurationLoader(FileConfigurationLoader):
         return super().supports(source) and \
             Utils.has_extension(source, 'json')
 
-    def _load_file(self, file: TextIO) -> dict:
+    def _load_file(self, file: IO[Any]) -> dict:
         super()._load_file(file)
         return Utils.always_dict(json.load(file))
