@@ -1,4 +1,4 @@
-from typing import Any, TextIO
+from typing import Any, IO
 
 from wg_federation.data_transformation.loader.file.file_configuration_loader import FileConfigurationLoader
 from wg_federation.utils.utils import Utils
@@ -13,6 +13,6 @@ class TextFileConfigurationLoader(FileConfigurationLoader):
         return super().supports(source) and \
             Utils.has_extension(source, r'(digest|sha([0-9]{3})?|md5|sig|txt)')
 
-    def _load_file(self, file: TextIO) -> dict:
+    def _load_file(self, file: IO[Any]) -> dict:
         super()._load_file(file)
         return {file.name: file.read()}
