@@ -1,4 +1,4 @@
-from typing import Any, TextIO
+from typing import Any, IO
 
 import yaml
 
@@ -15,6 +15,6 @@ class YamlFileConfigurationLoader(FileConfigurationLoader):
         return super().supports(source) and \
             Utils.has_extension(source, r'(yaml|yml)')
 
-    def _load_file(self, file: TextIO) -> dict:
+    def _load_file(self, file: IO[Any]) -> dict:
         super()._load_file(file)
         return Utils.always_dict(yaml.safe_load(file))
