@@ -1,5 +1,5 @@
 import json
-from typing import Any, TextIO
+from typing import Any, IO
 
 from wg_federation.data_transformation.saver.file.file_configuration_saver import FileConfigurationSaver
 from wg_federation.utils.utils import Utils
@@ -14,6 +14,6 @@ class JsonFileConfigurationSaver(FileConfigurationSaver):
         return super().supports(data, destination) and \
             Utils.has_extension(destination, 'json')
 
-    def _save_data(self, data: dict, file: TextIO) -> None:
+    def _save_data(self, data: dict, file: IO[Any]) -> None:
         super()._save_data(data, file)
         json.dump(data, file)
