@@ -1,5 +1,5 @@
 from types import ModuleType
-from typing import Any, TextIO
+from typing import Any, IO
 
 from wg_federation.data_transformation.saver.file.file_configuration_saver import FileConfigurationSaver
 from wg_federation.utils.utils import Utils
@@ -19,7 +19,7 @@ class TextFileConfigurationSaver(FileConfigurationSaver):
         return super().supports(data, destination) and \
             Utils.has_extension(destination, r'(digest|sha([0-9]{3})?|md5|sig|txt)')
 
-    def _save_data(self, data: dict, file: TextIO) -> None:
+    def _save_data(self, data: dict, file: IO[Any]) -> None:
         super()._save_data(data, file)
 
         file.write(self._os_lib.linesep.join(
