@@ -1,4 +1,4 @@
-from typing import Any, TextIO
+from typing import Any, IO
 
 import yaml
 
@@ -15,6 +15,6 @@ class YamlFileConfigurationSaver(FileConfigurationSaver):
         return super().supports(data, destination) and \
             Utils.has_extension(destination, '(yaml|yml)')
 
-    def _save_data(self, data: dict, file: TextIO) -> None:
+    def _save_data(self, data: dict, file: IO[Any]) -> None:
         super()._save_data(data, file)
         yaml.safe_dump(data, file)
