@@ -1,7 +1,9 @@
 import argparse
+import hashlib
 import logging
 import os
 import pathlib
+import subprocess
 from argparse import ArgumentParser
 
 import portalocker
@@ -12,8 +14,11 @@ from Cryptodome.Hash import Poly1305
 from dependency_injector import containers, providers
 from nacl import public
 
-from wg_federation.controller.api.hq_get_private_key_controller import HQGetPrivateKeyController
+from wg_federation.concurrent_worker.implementation.wireguard_interface_reload_worker import \
+    WireguardInterfaceReloadWorker
+from wg_federation.concurrent_worker.worker_container import WorkerContainer
 from wg_federation.constants import __version__, HAS_SYSTEMD
+from wg_federation.controller.api.hq_get_private_key_controller import HQGetPrivateKeyController
 from wg_federation.controller.baseline.configure_logging_controller import ConfigureLoggingController
 from wg_federation.controller.bootstrap.hq_bootstrap_controller import HQBootstrapController
 from wg_federation.crypto.cryptographic_key_deriver import CryptographicKeyDeriver
@@ -42,7 +47,10 @@ from wg_federation.data_transformation.saver.proxy.encrypt_configuration_saver_p
 from wg_federation.data_transformation.saver.proxy.normalize_filter_configuration_saver_proxy import \
     NormalizeFilterConfigurationSaverProxy
 from wg_federation.data_transformation.saver.proxy.sign_configuration_saver_proxy import SignConfigurationSaverProxy
-from wg_federation.event.hq.wireguard_interface_configuration_event_subscriber import WireguardInterfaceConfigurationEventSubscribe
+from wg_federation.event.hq.wireguard_interface_configuration_event_subscriber import \
+    WireguardInterfaceConfigurationEventSubscriber
+from wg_federation.event.wg_configuration.wireguard_interface_system_reload_event_subscriber import \
+    WireguardInterfaceSystemReloadEventSubscriber
 from wg_federation.input.manager.input_manager import InputManager
 from wg_federation.input.reader.argument_reader import ArgumentReader
 from wg_federation.input.reader.configuration_file_reader import ConfigurationFileReader
@@ -53,6 +61,7 @@ from wg_federation.state.manager.state_data_manager import StateDataManager
 if HAS_SYSTEMD:
     from systemd.journal import JournalHandler
 
+
 # Because it's how the DI lib works
 # pylint: disable=too-many-instance-attributes
 
@@ -70,10 +79,16 @@ class Container(containers.DynamicContainer):
         early_debug: bool = 'True' == os.getenv(EnvironmentVariableReader.get_real_env_var_name('DEBUG')) or \
                             self.EARLY_DEBUG
 
-        # data input
+        # ########## #
+        # Data Input #
+        # ########## #
+
         self.user_input = providers.Object()
 
-        # logging
+        ###
+        # Logging
+        ###
+
         _logger = logging.getLogger('root')
         _logger_console_handler = logging.StreamHandler()
         if HAS_SYSTEMD:
@@ -95,7 +110,21 @@ class Container(containers.DynamicContainer):
 
         self.root_logger = providers.Object(_logger)
 
-        # data transformation
+        ###
+        # Concurrent Worker
+        ###
+
+        self.worker_container = providers.Factory(
+            WorkerContainer,
+            logger=self.root_logger,
+        )
+
+        self.delayed_tasks = self.worker_container()
+
+        ###
+        # Data Transformation
+        ###
+
         self.configuration_location_finder = providers.Singleton(
             ConfigurationLocationFinder,
             user_input=self.user_input,
@@ -137,13 +166,16 @@ class Container(containers.DynamicContainer):
             logger=self.root_logger
         )
 
-        # Crypto
-        self.wireguard_key_generator = providers.Singleton(
+        ###
+        # Cryptography
+        ###
+
+        self.wireguard_key_generator = providers.ThreadSafeSingleton(
             WireguardKeyGenerator,
             nacl_public_lib=public,
             cryptodome_random_lib=Random,
         )
-        self.cryptographic_key_deriver = providers.Singleton(
+        self.cryptographic_key_deriver = providers.ThreadSafeSingleton(
             CryptographicKeyDeriver,
             user_input=self.user_input,
             configuration_location_finder=self.configuration_location_finder,
@@ -151,7 +183,7 @@ class Container(containers.DynamicContainer):
             configuration_saver=self.configuration_saver,
             cryptodome_random_lib=Random,
         )
-        self.message_signer = providers.Singleton(
+        self.message_signer = providers.ThreadSafeSingleton(
             MessageSigner,
             cryptographic_key_deriver=self.cryptographic_key_deriver,
             cryptodome_poly1305=Poly1305
@@ -162,7 +194,19 @@ class Container(containers.DynamicContainer):
             cryptodome_aes=AES
         )
 
-        # data transformation proxies
+        ###
+        # Observer
+        ###
+
+        self.event_dispatcher = providers.Factory(
+            EventDispatcher,
+            logger=self.root_logger,
+        )
+
+        ###
+        # Data Transformation Proxies
+        ###
+
         self.verify_signature_configuration_loader_proxy_factory = providers.Factory(
             VerifySignatureConfigurationLoaderProxy,
             configuration_location_finder=self.configuration_location_finder,
@@ -187,13 +231,29 @@ class Container(containers.DynamicContainer):
             digest_configuration_saver=self.configuration_saver,
         )
 
-        # input
-        self.environment_variable_reader = providers.Singleton(
+        ###
+        # Observer Impl
+        ###
+
+        self.hq_event_dispatcher = providers.ThreadSafeSingleton(
+            EventDispatcher,
+            logger=self.root_logger,
+        )
+        self.wg_configuration_event_dispatcher = providers.ThreadSafeSingleton(
+            EventDispatcher,
+            logger=self.root_logger,
+        )
+
+        ###
+        # Data Input
+        ###
+
+        self.environment_variable_reader = providers.ThreadSafeSingleton(
             EnvironmentVariableReader,
             logger=self.root_logger
         )
-        self.argument_parser = providers.Singleton(ArgumentParser)
-        self.configuration_file_reader = providers.Singleton(
+        self.argument_parser = providers.ThreadSafeSingleton(ArgumentParser)
+        self.configuration_file_reader = providers.ThreadSafeSingleton(
             ConfigurationFileReader,
             logger=self.root_logger,
             configuration_loader=self.configuration_loader
@@ -211,29 +271,11 @@ class Container(containers.DynamicContainer):
             logger=self.root_logger
         )
 
-        # observer
-
-        self.event_dispatcher = providers.Factory(
-            EventDispatcher,
-            logger=self.root_logger,
-        )
-
-        self.hq_event_dispatcher = providers.ThreadSafeSingleton(
-            EventDispatcher,
-            logger=self.root_logger,
-            subscribers=providers.List(
-                providers.ThreadSafeSingleton(
-                    WireguardInterfaceConfigurationEventSubscribe,
-                    os_lib=os,
-                    configuration_location_finder=self.configuration_location_finder,
-                    configuration_locker=self.configuration_locker,
-                )
-            )
-        )
-
+        ###
         # State
+        ###
 
-        self.state_manager_configuration_loader = providers.Singleton(
+        self.state_manager_configuration_loader = providers.ThreadSafeSingleton(
             DecryptConfigurationLoaderProxy,
             message_encrypter=self.message_encrypter,
             configuration_loader=providers.Singleton(
@@ -244,8 +286,7 @@ class Container(containers.DynamicContainer):
                 digest_configuration_loader=self.configuration_loader,
             )
         )
-
-        self.state_manager_configuration_saver = providers.Singleton(
+        self.state_manager_configuration_saver = providers.ThreadSafeSingleton(
             NormalizeFilterConfigurationSaverProxy,
             configuration_saver=providers.Singleton(
                 EncryptConfigurationSaverProxy,
@@ -259,8 +300,7 @@ class Container(containers.DynamicContainer):
                 )
             )
         )
-
-        self.state_data_manager = providers.Singleton(
+        self.state_data_manager = providers.ThreadSafeSingleton(
             StateDataManager,
             configuration_location_finder=self.configuration_location_finder,
             configuration_loader=self.state_manager_configuration_loader,
@@ -268,10 +308,43 @@ class Container(containers.DynamicContainer):
             configuration_locker=self.configuration_locker,
             wireguard_key_generator=self.wireguard_key_generator,
             event_dispatcher=self.hq_event_dispatcher,
-            logger=self.root_logger
+            logger=self.root_logger,
+            user_input=self.user_input,
         )
 
-        # controllers
+        ###
+        # Event Subscribers
+        ###
+
+        self.hq_event_dispatcher.add_kwargs(subscribers=providers.List(
+            providers.ThreadSafeSingleton(
+                WireguardInterfaceConfigurationEventSubscriber,
+                os_lib=os,
+                configuration_locker=self.configuration_locker,
+                event_dispatcher=self.wg_configuration_event_dispatcher,
+            )
+        ))
+
+        self.wg_configuration_event_dispatcher.add_kwargs(subscribers=providers.List(
+            providers.ThreadSafeSingleton(
+                WireguardInterfaceSystemReloadEventSubscriber,
+                user_input=self.user_input,
+                delayed_tasks=self.delayed_tasks,
+                wireguard_interface_reload_worker_factory=providers.Factory(
+                    WireguardInterfaceReloadWorker,
+                    hashlib=hashlib,
+                    state_data_manager=self.state_data_manager,
+                    logger=self.root_logger,
+                    subprocess_lib=subprocess,
+                ).provider,
+                hashlib=hashlib
+            )
+        ))
+
+        ###
+        # Controllers
+        ###
+
         self.controller_dispatcher = providers.ThreadSafeSingleton(
             EventDispatcher,
             logger=self.root_logger,
